#ifndef LIBKYPROCESSSEC_H
#define LIBKYPROCESSSEC_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 设置进程不可被杀死
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_set_anti_killed(const char *filepath);

/**
 * @brief 取消设置进程不可被杀死
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_cancel_anti_killed(const char *filepath);

/**
 * @brief 设置进程可执行
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_set_executable(const char *filepath);

/**
 * @brief 取消设置进程可执行
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_cancel_executable(const char *filepath);

/**
 * @brief 设置内核模块不可卸载
 * @param filename[in] 文件名
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_kmod_set_anti_unloaded(const char *filename);

/**
 * @brief 取消设置内核模块不可卸载
 * @param filename[in] 文件名
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_kmod_cancel_anti_unloaded(const char *filename);

/**
 * @brief 设置进程可以联网
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_enable_networking(const char *filepath);

/**
 * @brief 设置进程不可联网
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_process_disable_networking(const char *filepath);

#ifdef __cplusplus
}
#endif

#endif//LIBKYPROCESSSEC_H
